==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicProgressBarUI__24Animator.h <==
// class javax.swing.plaf.basic.BasicProgressBarUI$Animator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 42a47f3361445b06 javax_swing_plaf_basic_BasicProgressBarUI__24Animator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_
#define _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object;
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$_init$179faee0854de946(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$_init$b228ef868b7ce0f9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs {
    _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object {
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicProgressBarUI__24Animator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicProgressBarUI__24Animator.h <==
// class javax.swing.plaf.basic.BasicProgressBarUI$Animator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 42a47f3361445b06 javax_swing_plaf_basic_BasicProgressBarUI__24Animator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_
#define _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object;
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$_init$179faee0854de946(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$_init$b228ef868b7ce0f9(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vmethods	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicProgressBarUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs {
    _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_refs	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$sub_nonrefs	javax_swing_plaf_basic_BasicProgressBarUI__24Animator;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$object {
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$vtype _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicProgressBarUI__24Animator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicProgressBarUI__24Animator$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicProgressBarUI__24Animator_H_ */
